==> eslint_5.0.1~dfsg.orig.tar.xz: eslint-5.0.1/.github/ISSUE_TEMPLATE/BUG_REPORT.md <==
---
name: Bug report
about: Report an issue with ESLint or rules bundled with ESLint

---

<!--
    ESLint adheres to the [JS Foundation Code of Conduct](https://js.foundation/community/code-of-conduct).

    This template is for bug reports. If you are here for another reason, please see below:

    1. To propose a new rule: https://eslint.org/docs/developer-guide/contributing/new-rules
    2. To request a rule change: https://eslint.org/docs/developer-guide/contributing/rule-changes
    3. To request a change that is not a bug fix, rule change, or new rule: https://eslint.org/docs/developer-guide/contributing/changes
    4. If you have any questions, please stop by our chatroom: https://gitter.im/eslint/eslint

    Note that leaving sections blank will make it difficult for us to troubleshoot and we may have to close the issue.
-->

**Tell us about your environment**

* **ESLint Version:**
* **Node Version:**
* **npm Version:**

**What parser (default, Babel-ESLint, etc.) are you using?**

**Please show your full configuration:**

<details>
<summary>Configuration</summary>

<!-- Paste your configuration below: -->
```js

```

</details>

**What did you do? Please include the actual source code causing the issue, as well as the command that you used to run ESLint.**

<!-- Paste the source code below: -->
```js

```

<!-- Paste the command you used to run ESLint: -->
```bash

```

**What did you expect to happen?**

**What actually happened? Please include the actual, raw output from ESLint.**

==> eslint_6.4.0~dfsg+~6.1.9.orig.tar.xz: eslint-6.4.0/.github/ISSUE_TEMPLATE/BUG_REPORT.md <==
---
name: "\U0001F41E  Bug report"
about: Report an issue with ESLint or rules bundled with ESLint
title: ''
labels: bug, triage
assignees: ''

---

<!--
    ESLint adheres to the [JS Foundation Code of Conduct](https://js.foundation/community/code-of-conduct).

    This template is for bug reports. If you are here for another reason, please see below:

    1. To propose a new rule: https://eslint.org/docs/developer-guide/contributing/new-rules
    2. To request a rule change: https://eslint.org/docs/developer-guide/contributing/rule-changes
    3. To request a change that is not a bug fix, rule change, or new rule: https://eslint.org/docs/developer-guide/contributing/changes
    4. If you have any questions, please stop by our chatroom: https://gitter.im/eslint/eslint

    Note that leaving sections blank will make it difficult for us to troubleshoot and we may have to close the issue.
-->

**Tell us about your environment**

* **ESLint Version:**
* **Node Version:**
* **npm Version:**

**What parser (default, Babel-ESLint, etc.) are you using?**

**Please show your full configuration:**

<details>
<summary>Configuration</summary>

<!-- Paste your configuration below: -->
```js

```

</details>

**What did you do? Please include the actual source code causing the issue, as well as the command that you used to run ESLint.**

<!-- Paste the source code below: -->
```js

```

<!-- Paste the command you used to run ESLint: -->
```bash

```

**What did you expect to happen?**


**What actually happened? Please include the actual, raw output from ESLint.**


**Are you willing to submit a pull request to fix this bug?**
